@@ -35,13 +35,13 @@ class ConfigWizard : public QWizard
 {
     Q_OBJECT
 public:
-    ConfigWizard(QWidget *parent);
+    explicit ConfigWizard(QWidget *parent);
     ~ConfigWizard();
 
     bool configurationNeeded();
     bool requestConfiguration();
 
-public slots:
+public Q_SLOTS:
     void saveConfig();
 
 protected:
